KVSInterface<K, V> class

Inheritance
Implementers

Constructors

KVSInterface({String name = 'default', String? documentDirectory})

Properties

documentDirectory String?
getter/setter pairinherited
exists Future<bool>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsBytes() Future<Uint8List>
override
readAsString() Future<String>
override
toString() String
A string representation of this object.
inherited
writeAsBytes(Uint8List data) Future<void>
override
writeAsString(String data) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited